@@ -1,4 +1,4 @@
-# Copyright (c) 2020, 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2020  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -23,17 +23,11 @@
 # SUCH DAMAGE.
 """Simple tests for the validation routine."""
 
-try:
-    from typing import Any, Dict, List, Optional, Tuple  # noqa: H301
-except ImportError:
-    pass
-
 import json
 
-try:
-    import mock
-except ImportError:
-    from . import fake_mock as mock  # type: ignore
+from unittest import mock
+
+from typing import Any, Dict, List, Optional, Tuple  # noqa: H301
 
 try:
     import pytest  # type: ignore
@@ -45,16 +39,15 @@ import trivval
 from . import data as tdata
 
 
-def do_test(value, schema, backwards=False):
-    # type: (Dict[str, Any], Dict[str, Any], bool) -> None
+def do_test(
+    value: Dict[str, Any], schema: Dict[str, Any], backwards: bool = False
+) -> None:
     """Run the tests for a specific value against a schema."""
 
-    def test_extra_succeed():
-        # type: () -> None
+    def test_extra_succeed() -> None:
         trivval.validate_dict(value, schema, 0)
 
-    def test_extra_fail():
-        # type: () -> None
+    def test_extra_fail() -> None:
         with pytest.raises(trivval.ValidationError) as err:
             trivval.validate_dict(value, schema, 0)
         assert err.value.path[-1] != "a,more"
@@ -104,8 +97,7 @@ def do_test(value, schema, backwards=False):
     test_extra()
 
 
-def test_exact():
-    # type: () -> None
+def test_exact() -> None:
     """Test against the same version."""
     for version in sorted(tdata.VALUES.keys()):
         schema = tdata.SCHEMA[version]
@@ -113,8 +105,7 @@ def test_exact():
             do_test(value, schema)
 
 
-def test_backwards():
-    # type: () -> None
+def test_backwards() -> None:
     """Test against an earlier version."""
     for current_version in sorted(tdata.VALUES.keys()):
         for earlier_version in sorted(
@@ -127,8 +118,7 @@ def test_backwards():
                 do_test(value, schema, backwards=True)
 
 
-def test_breaking():
-    # type: () -> None
+def test_breaking() -> None:
     """Make sure validation fails after a breaking change."""
     for current_version in sorted(tdata.VALUES.keys()):
         for other_version in sorted(
@@ -140,15 +130,15 @@ def test_breaking():
                     trivval.validate_dict(value, schema, 0)
 
 
-def test_schema():
-    # type: () -> None
+def test_schema() -> None:
     """Make sure validation succeeds with all schemas."""
-    called = [
+    called: List[Optional[Tuple[Dict[str, Any], trivval.SchemaType, int]]] = [
         None
-    ]  # type: List[Optional[Tuple[Dict[str, Any], trivval.SchemaType, int]]]
+    ]
 
-    def mock_validate_dict(value, schema, flags):
-        # type: (Dict[str, Any], trivval.SchemaType, int) -> None
+    def mock_validate_dict(
+        value: Dict[str, Any], schema: trivval.SchemaType, flags: int
+    ) -> None:
         called.append((value, schema, flags))
 
     for version, values in tdata.VALUES.items():
@@ -179,26 +169,9 @@ def test_schema():
             ]
 
 
-def test_exact_json():
-    # type: () -> None
+def test_exact_json() -> None:
     """Test against the same version after a round trip through JSON."""
     for version in sorted(tdata.VALUES.keys()):
         schema = tdata.SCHEMA[version]
         for value in tdata.VALUES[version]:
             do_test(json.loads(json.dumps(value)), schema)
-
-
-def test_optional():
-    # type: () -> None
-    """Test "?key" not present or present as a null value."""
-    schema = {"first": str, "?second": int}
-
-    trivval.validate_dict({"first": "hello"}, schema, 0)
-    trivval.validate_dict({"first": "hello", "second": None}, schema, 0)
-    trivval.validate_dict({"first": "goodbye", "second": 42}, schema, 0)
-
-    with pytest.raises(trivval.ValidationError):
-        trivval.validate_dict({"second": 42}, schema, 0)
-
-    with pytest.raises(trivval.ValidationError):
-        trivval.validate_dict({"first": "1", "second": "2"}, schema, 0)
